import request from '@/utils/request'

// 查询车辆消费管理列表
export function listRescueCarSpend(query) {
  return request({
    url: '/rescue/rescueCarSpend/list',
    method: 'get',
    params: query
  })
}

// 查询车辆消费管理详细
export function getRescueCarSpend(id) {
  return request({
    url: '/rescue/rescueCarSpend/' + id,
    method: 'get'
  })
}

// 新增车辆消费管理
export function addRescueCarSpend(data) {
  return request({
    url: '/rescue/rescueCarSpend',
    method: 'post',
    data: data
  })
}

// 修改车辆消费管理
export function updateRescueCarSpend(data) {
  return request({
    url: '/rescue/rescueCarSpend',
    method: 'put',
    data: data
  })
}

// 删除车辆消费管理
export function delRescueCarSpend(id) {
  return request({
    url: '/rescue/rescueCarSpend/' + id,
    method: 'delete'
  })
}

export function listCar() {
  return request({
    url: '/system/rescueCar/list',
    method: 'get',
    params: {
      pageNo:1,
      pageSize:100
    }
  })
}

export function exportCarSpend(params) {
  return request({
    url: 'rescue/rescueCarSpend/export',
    method: 'get',
    params,
    responseType: 'blob'
  })
}
